@@ -1,13 +1,13 @@
-import urllib.parse
 import re
-
-from uuid import UUID
+import urllib.parse
 from pathlib import Path
 from time import sleep
 from typing import Optional
+from uuid import UUID
 
 import click
 import requests
+from requests import HTTPError, Response
 
 
 class URLGenerator:
@@ -62,7 +62,7 @@ def ingest_tiles(context: click.Context, document_id: Optional[UUID], container:
             "filename": container.name,
         },
     )
-    response.raise_for_status()
+    handle_response_errors(response)
     response_data = response.json()
     upload_url = response_data["upload_url"]
     ingest_id = response_data["id"]
@@ -75,7 +75,7 @@ def ingest_tiles(context: click.Context, document_id: Optional[UUID], container:
     click.echo("Processing")
     http.post(process_url)
     response = http.get(task_url)
-    response.raise_for_status()
+    handle_response_errors(response)
     response_data = response.json()
 
     delay = 1
@@ -86,7 +86,7 @@ def ingest_tiles(context: click.Context, document_id: Optional[UUID], container:
         if delay < 60:
             delay += 1
         response = http.get(task_url)
-        response.raise_for_status()
+        handle_response_errors(response)
         response_data = response.json()
 
     if response_data["state"] == "completed":
@@ -134,3 +134,11 @@ def upload_file(file: Path, url: str):
                 chunk = None
             else:
                 response.raise_for_status()
+
+def handle_response_errors(response: Response):
+    try:
+        response.raise_for_status()
+    except HTTPError as error:
+        print(error)
+        print(error.response.json()["errors"][0]["message"])
+        exit()
